==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/38/380d8b61a214f6955a2cde863c37082f.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/LeadBundle/Helper/CampaignEventHelper.php */
class __TwigTemplate_60f5713e80c328cda177b83a48051179 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\LeadBundle\\Helper;

use Mautic\\LeadBundle\\Entity\\Lead;
use Mautic\\LeadBundle\\Event\\ListChangeEvent;

class CampaignEventHelper
{
    public static function validatePointChange(\$event, Lead \$lead): bool
    {
        \$properties  = \$event['properties'];
        \$checkPoints = \$properties['points'];

        if (!empty(\$checkPoints)) {
            \$points = \$lead->getPoints();
            if (\$points < \$checkPoints) {
                return false;
            }
        }

        return true;
    }

    public static function validateListChange(ListChangeEvent \$eventDetails, \$event): bool
    {
        \$limitAddTo      = \$event['properties']['addedTo'];
        \$limitRemoveFrom = \$event['properties']['removedFrom'];
        \$list            = \$eventDetails->getList();

        if (\$eventDetails->wasAdded() && !empty(\$limitAddTo) && !in_array(\$list->getId(), \$limitAddTo)) {
            return false;
        }

        if (\$eventDetails->wasRemoved() && !empty(\$limitRemoveFrom) && !in_array(\$list->getId(), \$limitRemoveFrom)) {
            return false;
        }

        return true;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/LeadBundle/Helper/CampaignEventHelper.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/LeadBundle/Helper/CampaignEventHelper.php", "/var/www/mautic-ktn/app/bundles/LeadBundle/Helper/CampaignEventHelper.php");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/38/380d8b61a214f6955a2cde863c37082f.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/LeadBundle/Helper/CampaignEventHelper.php */
class __TwigTemplate_60f5713e80c328cda177b83a48051179 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\LeadBundle\\Helper;

use Mautic\\LeadBundle\\Entity\\Lead;
use Mautic\\LeadBundle\\Event\\ListChangeEvent;

class CampaignEventHelper
{
    public static function validatePointChange(\$event, Lead \$lead): bool
    {
        \$properties  = \$event['properties'];
        \$checkPoints = \$properties['points'];

        if (!empty(\$checkPoints)) {
            \$points = \$lead->getPoints();
            if (\$points < \$checkPoints) {
                return false;
            }
        }

        return true;
    }

    public static function validateListChange(ListChangeEvent \$eventDetails, \$event): bool
    {
        \$limitAddTo      = \$event['properties']['addedTo'];
        \$limitRemoveFrom = \$event['properties']['removedFrom'];
        \$list            = \$eventDetails->getList();

        if (\$eventDetails->wasAdded() && !empty(\$limitAddTo) && !in_array(\$list->getId(), \$limitAddTo)) {
            return false;
        }

        if (\$eventDetails->wasRemoved() && !empty(\$limitRemoveFrom) && !in_array(\$list->getId(), \$limitRemoveFrom)) {
            return false;
        }

        return true;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/LeadBundle/Helper/CampaignEventHelper.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/LeadBundle/Helper/CampaignEventHelper.php", "/var/www/html/mauticGIT-Test/app/bundles/LeadBundle/Helper/CampaignEventHelper.php");
    }
}
